]> git.ipfire.org Git - thirdparty/coreutils.git/commitdiff
rename variable
authorJim Meyering <jim@meyering.net>
Thu, 7 May 1998 15:54:44 +0000 (15:54 +0000)
committerJim Meyering <jim@meyering.net>
Thu, 7 May 1998 15:54:44 +0000 (15:54 +0000)
src/tac.c

index a4436c83d6f3dfc5aa950630c191c903c8fac528..f5cf8b4ed3c57129ff15fa48c76a982297dd4f7c 100644 (file)
--- a/src/tac.c
+++ b/src/tac.c
@@ -452,13 +452,12 @@ tac_stdin (void)
   return errors;
 }
 
-/* BUF_END_PLUS_ONE points one byte past the end of the buffer
-   to be searched.  */
+/* BUF_END points one byte past the end of the buffer to be searched.  */
 
 static void *
-memrchr (const char *buf_start, const char *buf_end_plus_one, int c)
+memrchr (const char *buf_start, const char *buf_end, int c)
 {
-  const char *p = buf_end_plus_one;
+  const char *p = buf_end;
   while (buf_start <= --p)
     {
       if (*(const unsigned char *) p == c)